@@ -2,25 +2,18 @@
 # Copyright (C) 2012 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
-import urllib2, socket, re, glob
+import urllib2, re, glob
 import time, platform, sys, zipfile, os, cStringIO
-import threading
 import wx
-import  wx.lib.filebrowsebutton
+import wx.lib.filebrowsebutton
 try:
     from agw import hyperlink as wxhl
 except ImportError: # if it's not there locally, try the wxPython lib.
     import wx.lib.hyperlink as wxhl
 import psychopy
+from psychopy import web
 from psychopy.app import dialogs
 from psychopy import logging
-from psychopy import preferences
-prefs=preferences.Preferences()
-
-socket.setdefaulttimeout(2)
-
-global proxies
-proxies=None #if this is populated then it has been set up already
 
 versionURL = "http://www.psychopy.org/version.txt"
 
@@ -33,9 +26,9 @@ def makeConnections(app):
     """A helper function to be launched from a thread. Will setup proxies and check for updates.
     Should be run from a thread while the program continues to load.
     """
-    if proxies is None:
-        setupProxy()
-    if proxies==0:
+    if web.proxies is None:
+        web.setupProxy()
+    if web.proxies==0:
         return
     if app.prefs.connections['allowUsageStats']:
         sendUsageStats()
@@ -64,25 +57,24 @@ def getLatestVersionInfo():
     return latest
 
 class Updater:
-    def __init__(self,app=None, runningVersion=None, proxy=None):
+    def __init__(self,app=None, runningVersion=None):
         """The updater will check for updates and download/install them if necess.
         Several dialogs may be created as needed during the process.
 
         Usage::
 
             if app.prefs['AutoUpdate']:
-                app.updates=Updater(app, proxy)
+                app.updates=Updater(app)
                 app.updater.checkForUpdates()#if updates are found further dialogs will prompt
         """
-        global proxies
         self.app=app
         if runningVersion==None:  self.runningVersion=psychopy.__version__
         else:  self.runningVersion=runningVersion
 
-        self.headers = {'User-Agent' : 'Mozilla/5.0'}
+        #self.headers = {'User-Agent' : psychopy.constants.PSYCHOPY_USERAGENT}
         self.latest=None
-        if proxies==None:
-            setupProxy()
+        if web.proxies==None:
+            web.setupProxy()
 
     def getLatestInfo(self, warnMsg=False):
         #open page
@@ -132,7 +124,7 @@ class Updater:
                     self.app.followLink(url=self.app.urls['downloads'])
                 if resp==wx.ID_NO:
                     self.app.followLink(url=self.app.urls['changelog'])
-        elif not confirmationDlg:#don't confirm but return the latest version info
+        elif not confirmationDlg:#do nothing
             return 0
         else:
             msg= "You are running the latest version of PsychoPy (%s). " %(self.runningVersion)
@@ -148,7 +140,7 @@ class SuggestUpdateDialog(wx.Dialog):
     """A dialog explaining that a new version is available with a link to the changelog
     """
     def __init__(self,latest,runningVersion):
-        wx.Dialog.__init__(self,None,-1,title='PsychoPy2 auto-updater')
+        wx.Dialog.__init__(self,None,-1,title='PsychoPy2 Updates')
         sizer=wx.BoxSizer(wx.VERTICAL)
 
         #info about current version
@@ -163,7 +155,11 @@ class SuggestUpdateDialog(wx.Dialog):
         changelogLink = wxhl.HyperLinkCtrl(self, wx.ID_ANY, "View complete Changelog",
                                         URL="http://www.psychopy.org/changelog.html")
 
-        msg3 = wx.StaticText(self,-1,"Should PsychoPy update itself?")
+        if sys.platform.startswith('linux'):
+            msg3 = wx.StaticText(self,-1,"You can update PsychoPy with your package manager")
+        else:
+            msg3 = wx.StaticText(self,-1,"Should PsychoPy update itself?")
+
         sizer.Add(msg1,flag=wx.ALL|wx.CENTER,border=15)
         sizer.Add(msg2,flag=wx.RIGHT|wx.LEFT|wx.CENTER,border=15)
         sizer.Add(changelogLink,flag=wx.RIGHT|wx.LEFT|wx.CENTER,border=5)
@@ -171,18 +167,26 @@ class SuggestUpdateDialog(wx.Dialog):
 
         #add buttons
         btnSizer=wx.BoxSizer(wx.HORIZONTAL)
-        self.yesBtn=wx.Button(self,wx.ID_YES,'Yes')
-        self.cancelBtn=wx.Button(self,wx.ID_CANCEL,'Not now')
-        self.noBtn=wx.Button(self,wx.ID_NO,'Skip this version')
+
+        if sys.platform.startswith('linux'):#for linux there should be no 'update' option
+            self.cancelBtn=wx.Button(self,wx.ID_CANCEL,'Keep warning me')
+            self.cancelBtn.SetDefault()
+            self.noBtn=wx.Button(self,wx.ID_NO,'Stop warning me')
+        else:
+            self.yesBtn=wx.Button(self,wx.ID_YES,'Yes')
+            self.Bind(wx.EVT_BUTTON, self.onButton, id=wx.ID_YES)
+            self.cancelBtn=wx.Button(self,wx.ID_CANCEL,'Not now')
+            self.noBtn=wx.Button(self,wx.ID_NO,'Skip this version')
         self.Bind(wx.EVT_BUTTON, self.onButton, id=wx.ID_CANCEL)
-        self.Bind(wx.EVT_BUTTON, self.onButton, id=wx.ID_YES)
         self.Bind(wx.EVT_BUTTON, self.onButton, id=wx.ID_NO)
-        self.yesBtn.SetDefault()
         btnSizer.Add(self.noBtn, wx.ALIGN_LEFT)
         btnSizer.Add((60, 20), 0, wx.EXPAND)
         btnSizer.Add(self.cancelBtn, wx.ALIGN_RIGHT)
-        btnSizer.Add((5, 20), 0)
-        btnSizer.Add(self.yesBtn, wx.ALIGN_RIGHT)
+
+        if not sys.platform.startswith('linux'):
+            self.yesBtn.SetDefault()
+            btnSizer.Add((5, 20), 0)
+            btnSizer.Add(self.yesBtn, wx.ALIGN_RIGHT)
 
         #configure sizers and fit
         sizer.Add(btnSizer,flag=wx.ALIGN_RIGHT|wx.ALL,border=5)
@@ -451,14 +455,11 @@ class InstallUpdateDialog(wx.Dialog):
                     info+='Failed to update PsychoPy path in ', filename
                     return -1, info
         return nUpdates, info
-def sendUsageStats(proxy=None):
+def sendUsageStats():
     """Sends anonymous, very basic usage stats to psychopy server:
       the version of PsychoPy
       the system used (platform and version)
       the date
-
-    If http_proxy is set in the system environment variables these will be used automatically,
-    but additional proxies can be provided here as the argument proxies.
     """
 
     v=psychopy.__version__
@@ -467,8 +468,8 @@ def sendUsageStats(proxy=None):
 
     #urllib.install_opener(opener)
     #check for proxies
-    if proxies is None:
-        setupProxy()
+    if web.proxies is None:
+        web.setupProxy()
 
     #get platform-specific info
     if sys.platform=='darwin':
@@ -496,185 +497,3 @@ def sendUsageStats(proxy=None):
         logging.warning("Couldn't connect to psychopy.org\n"+\
             "Check internet settings (and proxy setting in PsychoPy Preferences.")
 
-
-def testProxy(handler, URL=None):
-    """
-    Test whether we can connect to a URL with the current proxy settings.
-
-    :Returns:
-
-        - True (success)
-        - a urllib2.URLError (which can be interrogated with .reason)
-        - a urllib2.HTTPError (which can be interrogated with .code)
-
-    """
-    if URL is None:
-        URL='http://www.google.com'#hopefully google isn't down!
-    req = urllib2.Request(URL)
-    opener = urllib2.build_opener(handler)
-    try:
-        page = opener.open(req).read(5)#open and read a few characters
-        return True
-    except urllib2.URLError, err:
-        return err
-    except urllib2.HTTPError, err:
-        return err
-
-def getPacFiles():
-    """Return a list of possible auto proxy .pac files being used,
-    based on the system registry (win32) or system preferences (OSX).
-    """
-    pacFiles=[]
-    if sys.platform=='win32':
-        try:
-            import _winreg as winreg#used from python 2.0-2.6
-        except:
-            import winreg#used from python 2.7 onwards
-        net = winreg.OpenKey(
-            winreg.HKEY_CURRENT_USER,
-            "Software\\Microsoft\\Windows\\CurrentVersion\\Internet Settings"
-        )
-        nSubs, nVals, lastMod = winreg.QueryInfoKey(net)
-        subkeys={}
-        for i in range(nVals):
-            thisName, thisVal, thisType=winreg.EnumValue(net,i)
-            subkeys[thisName]=thisVal
-        if 'AutoConfigURL' in subkeys.keys() and len(subkeys['AutoConfigURL'])>0:
-            pacFiles.append(subkeys['AutoConfigURL'])
-    elif sys.platform=='darwin':
-        import plistlib
-        sysPrefs = plistlib.readPlist('/Library/Preferences/SystemConfiguration/preferences.plist')
-        networks=sysPrefs['NetworkServices']
-        #loop through each possible network (e.g. Ethernet, Airport...)
-        for network in networks.items():
-            netKey, network=network#the first part is a long identifier
-            if 'ProxyAutoConfigURLString' in network['Proxies'].keys():
-                pacFiles.append(network['Proxies']['ProxyAutoConfigURLString'])
-    return pacFiles
-
-def getWpadFiles():
-    """
-    Return possible pac file locations from the standard set of .wpad locations
-
-    NB this method only uses the DNS method to search, not DHCP queries, and
-    so may not find all possible .pac locations.
-
-    See http://en.wikipedia.org/wiki/Web_Proxy_Autodiscovery_Protocol
-    """
-    domainParts = socket.gethostname().split('.')
-    pacURLs=[]
-    for ii in range(len(domainParts)):
-        domain = '.'.join(domainParts[ii:])
-        pacURLs.append("http://wpad."+domain+"/wpad.dat")
-    return pacURLs
-
-def proxyFromPacFiles(pacURLs=[],URL=None):
-    """Attempts to locate and setup a valid proxy server from pac file URLs
-
-    :Parameters:
-
-        - pacURLs : list
-
-            List of locations (URLs) to look for a pac file. This might come from
-            :func:`~psychopy.connections.getPacFiles` or
-            :func:`~psychopy.connections.getWpadFiles`.
-
-        - URL : string
-
-            The URL to use when testing the potential proxies within the files
-
-    :Returns:
-
-        - A urllib2.ProxyHandler if successful (and this will have been added as
-        an opener to the urllib2.
-        - -1 if no proxy was found in the files that allowed successful connection
-    """
-
-    if pacURLs==[]:#if given none try to find some
-        pacURLs = getPacFiles()
-    if pacURLs==[]:#if still empty search for wpad files
-        pacURLs = getWpadFiles()
-        #for each file search for valid urls and test them as proxies
-    for thisPacURL in pacURLs:
-        logging.debug('proxyFromPacFiles is searching file:\n  %s' %thisPacURL)
-        try:
-            response = urllib2.urlopen(thisPacURL, timeout=5.0)
-        except urllib2.URLError:
-            logging.debug("Failed to find PAC URL '%s' " %thisPacURL)
-            continue
-        pacStr = response.read()
-        #find the candidate PROXY strings (valid URLS)
-        possProxies = re.findall(r"PROXY [0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}:[0-9]{4}", pacStr)
-        for thisPoss in possProxies:
-            proxUrl = 'http://'+thisPoss[6:]
-            handler=urllib2.ProxyHandler({'http':proxUrl})
-            if testProxy(handler)==True:
-                logging.debug('successfully loaded: %s' %proxUrl)
-                urllib2.install_opener(urllib2.build_opener(handler))
-                return handler
-    return False
-
-def setupProxy():
-    """Set up the urllib proxy if possible.
-
-     The function will use the following methods in order to try and determine proxies:
-        #. standard urllib2.urlopen (which will use any statically-defined http-proxy settings)
-        #. previous stored proxy address (in prefs)
-        #. proxy.pac files if these have been added to system settings
-        #. auto-detect proxy settings (WPAD technology)
-
-     .. note:
-        This can take time, as each failed attempt to set up a proxy involves trying to load a URL and timing out. Best
-        to do in a separate thread.
-
-    :Returns:
-
-        True (success) or False (failure)
-    """
-    global proxies
-    #try doing nothing
-    proxies=urllib2.ProxyHandler(urllib2.getproxies())
-    if testProxy(proxies) is True:
-        logging.debug("Using standard urllib2 (static proxy or no proxy required)")
-        urllib2.install_opener(urllib2.build_opener(proxies))#this will now be used globally for ALL urllib2 opening
-        return 1
-
-    #try doing what we did last time
-    if len(prefs.connections['proxy'])>0:
-        proxies=urllib2.ProxyHandler({'http': prefs.connections['proxy']})
-        if testProxy(proxies) is True:
-            logging.debug('Using %s (from prefs)' %(prefs.connections['proxy']))
-            urllib2.install_opener(urllib2.build_opener(proxies))#this will now be used globally for ALL urllib2 opening
-            return 1
-        else:
-            logging.debug("Found a previous proxy but it didn't work")
-
-    #try finding/using a proxy.pac file
-    pacURLs=getPacFiles()
-    logging.debug("found pac files: %s" %pacURLs)
-    proxies=proxyFromPacFiles(pacURLs)
-    if proxies and hasattr(proxies, 'proxies') and len(proxies.proxies['http'])>0:
-        #save that proxy for future
-        prefs.connections['proxy']=proxies.proxies['http']
-        prefs.saveUserPrefs()
-        logging.debug('Using %s (from proxy PAC file)' %(prefs.connections['proxy']))
-        return 1
-
-    #try finding/using 'auto-detect proxy'
-    pacURLs=getWpadFiles()
-    proxies=proxyFromPacFiles(pacURLs)
-    if proxies and hasattr(proxies, 'proxies') and len(proxies.proxies['http'])>0:
-        #save that proxy for future
-        prefs.connections['proxy']=proxies.proxies['http']
-        prefs.saveUserPrefs()
-        logging.debug('Using %s (from proxy auto-detect)' %(prefs.connections['proxy']))
-        return 1
-
-    proxies=0
-    return 0
-
-if __name__=='__main__':
-    logging.console.setLevel(logging.DEBUG)
-    t0=time.time()
-    print setupProxy()
-    print 'that took %.2fs' %(time.time()-t0)
