@@ -10,13 +10,16 @@ from psychopy.platform_specific import rush
 from psychopy import logging
 import subprocess, shlex
 
-runningThreads=[]
+runningThreads=[] # just for backwards compatibility?
+pyoServers = []
 
 try:
     import pyglet
     havePyglet = True
+    checkPygletDuringWait = True # may not want to check, to preserve terminal window focus
 except:
     havePyglet = False
+    checkPygletDuringWait = False
 
 def quit():
     """Close everything and exit nicely (ending the experiment)
@@ -29,6 +32,12 @@ def quit():
             thisThread.stop()
             while thisThread.running==0:
                 pass#wait until it has properly finished polling
+    # could check serverCreated() serverBooted() but then need to import pyo
+    # checking serverCreated() does not tell you whether it was shutdown or not
+    for ps in pyoServers: # should only ever be one Server instance...
+        ps.stop()
+        wait(.25)
+        ps.shutdown()
     sys.exit(0)#quits the python session entirely
 
 #set the default timing mechanism
@@ -62,6 +71,50 @@ class Clock:
         time on the clock
         """
         self.timeAtLastReset=getTime()+newT
+    def add(self,t):
+        """Add more time to the clock's 'start' time (t0).
+
+        Note that, by adding time to t0, you make the current time appear less.
+        Can have the effect that getTime() returns a negative number that will
+        gradually count back up to zero.
+
+        e.g.::
+
+            timer = core.Clock()
+            timer.add(5)
+            while timer.getTime()<0:
+                #do something
+        """
+        self.timeAtLastReset += t
+
+class CountdownTimer(Clock):
+    """Similar to a Clock except that time counts down from the time of last reset
+
+    Typical usage::
+
+        timer = core.CountdownTimer()
+        timer.add(5)
+        while timer.getTime(): #after 5s will become negative
+            #do stuff
+    """
+    def getTime(self):
+        """Returns the current time on this clock in secs (sub-ms precision)
+        """
+        return self.timeAtLastReset-getTime()
+    def add(self,t):
+        """Add more time to the clock's 'start' time (t0).
+
+        Unlike the Clock.add() method this actually adds time to the apparent
+        current time. (It actually subtracts time from the stored t0)
+
+        e.g.::
+
+            timer = core.Clock()
+            timer.add(5)
+            while timer.getTime()>0:
+                #do something
+        """
+        self.timeAtLastReset += t
 
 def wait(secs, hogCPUperiod=0.2):
     """Wait for a given time period.
@@ -73,6 +126,12 @@ def wait(secs, hogCPUperiod=0.2):
 
     If you want to obtain key-presses during the wait, be sure to use pyglet and
     to hogCPU for the entire time, and then call event.getKeys() after calling core.wait()
+
+    If you want to suppress checking for pyglet events during the wait, do this once:
+        core.checkPygletDuringWait = False
+    and from then on you can do
+        core.wait(sec)
+    This will preserve terminal-window focus during command line usage.
     """
     #initial relaxed period, using sleep (better for system resources etc)
     if secs>hogCPUperiod:
@@ -82,21 +141,32 @@ def wait(secs, hogCPUperiod=0.2):
     #hog the cpu, checking time
     t0=getTime()
     while (getTime()-t0)<secs:
+        if not (havePyglet and checkPygletDuringWait):
+            continue
         #let's see if pyglet collected any event in meantime
         try:
+            # this takes focus away from command line terminal window:
             pyglet.media.dispatch_events()#events for sounds/video should run independently of wait()
             wins = pyglet.window.get_platform().get_default_display().get_windows()
             for win in wins: win.dispatch_events()#pump events on pyglet windows
         except:
             pass #presumably not pyglet
 
-def shellCall(shellCmd, stderr=False):
+def shellCall(shellCmd, stdin='', stderr=False):
     """Call a single system command with arguments, return its stdout.
-    Returns stdout,stderr if stderr is True. Does not handle pipes ("|").
+    Returns stdout,stderr if stderr is True.
+    Handles simple pipes, passing stdin to shellCmd (pipes are untested on windows)
+    can accept string or list as the first argument
     """
-    shellCmdList = shlex.split(shellCmd) # safely split into cmd+list-of-args, pipes fail
-    proc = subprocess.Popen(shellCmdList, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-    stdoutData, stderrData = proc.communicate()
+    if type(shellCmd) == str:
+        shellCmdList = shlex.split(shellCmd) # safely split into cmd+list-of-args, no pipes here
+    elif type(shellCmd) == list: # handles whitespace in filenames
+        shellCmdList = shellCmd
+    else:
+        return None, 'shellCmd requires a list or string'
+    proc = subprocess.Popen(shellCmdList, stdin=subprocess.PIPE,
+                            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    stdoutData, stderrData = proc.communicate(stdin)
     del proc
     if stderr:
         return stdoutData.strip(), stderrData.strip()
