@@ -33,29 +33,35 @@ def setGamma(pygletWindow=None, newGamma=1.0, rampType=None):
         newLUT = newLUT**(1/numpy.array(newGamma))# correctly handles 1 or 3x1 gamma vals
     setGammaRamp(pygletWindow, newLUT)
 
-def setGammaRamp(pygletWindow, newRamp):
+def setGammaRamp(pygletWindow, newRamp, nAttempts=3):
     """Sets the hardware look-up table, using platform-specific ctypes functions.
     For use with pyglet windows only (pygame has its ow routines for this).
     Ramp should be provided as 3x256 or 3x1024 array in range 0:1.0
+
+    On windows the first attempt to set the ramp doesn't always work. The parameter nAttemps
+    allows the user to determine how many attempts should be made before failing
     """
     if sys.platform=='win32':
-        newRamp= (255*newRamp).astype(numpy.uint16)
+        newRamp= (255.0*newRamp).astype(numpy.uint16)
         newRamp.byteswap(True)#necessary, according to pyglet post from Martin Spacek
-        success = windll.gdi32.SetDeviceGammaRamp(pygletWindow._dc, newRamp.ctypes)
-        if not success: raise AssertionError, 'SetDeviceGammaRamp failed'
+        for n in range(nAttempts):
+            success = windll.gdi32.SetDeviceGammaRamp(pygletWindow._dc, newRamp.ctypes)
+            if success:
+                break
+        assert success, 'SetDeviceGammaRamp failed'
 
     if sys.platform=='darwin':
         newRamp= (newRamp).astype(numpy.float32)
         LUTlength=newRamp.shape[1]
         error =carbon.CGSetDisplayTransferByTable(pygletWindow._screen.id, LUTlength,
                    newRamp[0,:].ctypes, newRamp[1,:].ctypes, newRamp[2,:].ctypes)
-        if error: raise AssertionError, 'CGSetDisplayTransferByTable failed'
+        assert not error, 'CGSetDisplayTransferByTable failed'
 
     if sys.platform.startswith('linux'):
         newRamp= (65535*newRamp).astype(numpy.uint16)
         success = xf86vm.XF86VidModeSetGammaRamp(pygletWindow._x_display, pygletWindow._x_screen_id, 256,
                     newRamp[0,:].ctypes, newRamp[1,:].ctypes, newRamp[2,:].ctypes)
-        if not success: raise AssertionError, 'XF86VidModeSetGammaRamp failed'
+        assert success, 'XF86VidModeSetGammaRamp failed'
 
 def getGammaRamp(pygletWindow):
     """Ramp will be returned as 3x256 array in range 0:1
@@ -63,22 +69,25 @@ def getGammaRamp(pygletWindow):
     if sys.platform=='win32':
         origramps = numpy.empty((3, 256), dtype=numpy.uint16) # init R, G, and B ramps
         success = windll.gdi32.GetDeviceGammaRamp(pygletWindow._dc, origramps.ctypes)
-        if not success: raise AssertionError, 'SetDeviceGammaRamp failed'
-        origramps.byteswap(True)
-        origramps=origramps/255.0#rescale to 0:1
+        if not success:
+            raise AssertionError, 'GetDeviceGammaRamp failed'
+        origramps=origramps/65535.0#rescale to 0:1
 
     if sys.platform=='darwin':
         origramps = numpy.empty((3, 256), dtype=numpy.float32) # init R, G, and B ramps
         n = numpy.empty([1],dtype=numpy.int)
         error =carbon.CGGetDisplayTransferByTable(pygletWindow._screen.id, 256,
                    origramps[0,:].ctypes, origramps[1,:].ctypes, origramps[2,:].ctypes, n.ctypes);
-        if error: raise AssertionError, 'CGSetDisplayTransferByTable failed'
+        if error:
+            raise AssertionError, 'CGSetDisplayTransferByTable failed'
 
     if sys.platform.startswith('linux'):
         origramps = numpy.empty((3, 256), dtype=numpy.uint16)
         success = xf86vm.XF86VidModeGetGammaRamp(pygletWindow._x_display, pygletWindow._x_screen_id, 256,
                     origramps[0,:].ctypes, origramps[1,:].ctypes, origramps[2,:].ctypes)
-        if not success: raise AssertionError, 'XF86VidModeGetGammaRamp failed'
+        if not success:
+            raise AssertionError, 'XF86VidModeGetGammaRamp failed'
+        origramps=origramps/65535.0#rescale to 0:1
 
     return origramps
 
