@@ -50,6 +50,9 @@ class PR650:
 
 
     """
+    longName = "PR650"
+    driverFor = ["pr650"]
+
     def __init__(self, port, verbose=None):
         if type(port) in [int, float]:
             self.portNumber = port #add one so that port 1=COM1
@@ -71,7 +74,8 @@ class PR650:
 
         #try to open the port
         if sys.platform in ['darwin', 'win32'] or sys.platform.startswith('linux'):
-            try:self.com = serial.Serial(self.portString)
+            try:
+                self.com = serial.Serial(self.portString)
             except:
                 self._error("Couldn't connect to port %s. Is it being used by another program?" %self.portString)
         else:
@@ -82,11 +86,14 @@ class PR650:
             self.com.setParity('N')#none
             self.com.setStopbits(1)
             try:
-                self.com.open()
-                self.isOpen=1
+                # Pyserial >=2.6 throws an exception when trying to open a serial port that
+                # is already open. Catching that exception is not an option here because
+                # PySerial only defines a single exception type (SerialException)
+                if not self.com.isOpen(): self.com.open()
             except:
                 self._error("Opened serial port %s, but couldn't connect to PR650" %self.portString)
-
+            else:
+                self.isOpen=1
         if self.OK:
             logging.info("Successfully opened %s" %self.portString)
             time.sleep(0.1) #wait while establish connection
@@ -255,6 +262,8 @@ class PR655(PR650):
         has become controlled by some other program.
 
     '''
+    longName = "PR655/PR670"
+    driverFor = ["pr655","pr670"]
     def __init__(self, port):
         self.type = None#get this from the device later
         self.com=False
